rucio-admin — Rucio 0.3.8 documentation

# rucio-admin

## Rucio Admin Utility

Author: | rucio@cern.ch
Date: | 2012-01-03
Copyright: | CERN
Version: | 2012.1-dev
Manual section: | 1
Manual group: | cloud computing

### SYNOPSIS

> rucio-admin <command> [options] [args]

### DESCRIPTION

glance-admin is a utility for managing and configuring Rucio.

### OPTIONS

> General options

> -v, –verbose
>   Print more verbose output
> –version
>   Print version
> -H, –host
>   Address of The Rucio API host
> -p, –port
>   Port the Rucio API host listens on.

### FILES

None

### SEE ALSO

- Rucio

### BUGS

- Trac server: Rucio